function Pnm = calculatePnm(theta, n_max)
%
% Calculation of normalized Legendre Functions using stable recursion
% formulas. 
%
% --Input--
%   theta       Co-Latitude (1x1)
%   n_max       Maximum degree (1x1)
%
% --Output--
%   Pnm         Legendre functions (n_max x n_max)
%
% Author: Anne Springer
% Date:  2015-08-24
%

t = cos(theta);

Pnm = zeros(n_max+1, n_max+1);
Pnm(1,1) = 1;
an = sqrt(3);

for n = 1:n_max    
    if n>1
        an = sqrt((2*n+1)/(2*n));
    end
    
    % P_{n,n} 
    Pnm(n+1, n+1) = an * sqrt(1-t^2)*Pnm(n,n);
    
    % P_{n,n-1}
    bn = sqrt((2*n + 1)*(2*n - 1)/((n+(n-1))*(n-(n-1))));
    Pnm(n+1, n) = bn*Pnm(n,n)*t;
    
    % P_{n,m}
    for m = 0:n-2
       bnm = sqrt((2*n + 1)*(2*n - 1)/((n+m)*(n-m)));
       cnm = sqrt((2*n+1)*(n-m-1)*(n+m-1)/((2*n-3)*(n+m)*(n-m))) ;
       Pnm(n+1, m+1) = bnm*t*Pnm(n, m+1) - cnm*Pnm(n-1, m+1); 
    end
end