function [cnm, snm] = sortCoefficients(x, n_max)

%
% SORTCOEFFICIENTS.m sorts spherical harmonic coefficients
%
% --Input--
%   x           Parameter vector containing the estimated spherical
%               harmonic coefficients (n x 1)
%   n_max       Maximum degree (1x1)
%
% --Output--
%   cnm, snm    Potential coefficients divided into sine component and
%               cosine component
%
% Author: Anne Springer
% Date:  2015-08-24
%

% Degree and order
idx = tril(ones(n_max+1))~=0;
degree = repmat((0:n_max)',1,n_max+1);
degree = degree(idx);
order = repmat(0:n_max,n_max+1,1);
order = order(idx);

% Cosine coefficients
cnm = zeros(n_max+1);
for i = 1:length(degree)
    cnm(degree(i)+1, order(i)+1) = x(i);
end

% Sine coefficients
snm = zeros(n_max+1);
for j = 1:length(degree(n_max+2:end))
    snm(degree(j+n_max+1)+1, order(j+n_max+1)+1) = x(i+j);
end

end
