function RotMati2e_dot = Ri2e_dot(grace_gps_time)

% RI2E_DOT returns the derivative of the rotation matrix from inertial
% frame to an Earth-fixed Earth-centered coordinate system. The rotation matrix
% is a simple Z-rotation, in which the rotation axes (Z) of the inertial and
% the Earth-fixed frames coincide. See also Ri2e.m%
%
% Input:        grace_gps_time = time (or times) in GRACE GPS seconds [Nx1]
%
% Outputs:      RotMati2e = Rotation martrix from inertial to Earth-fixed frame [Nx3x3]
%
% Remark:       This matrix shall be used only for simulation purposes, in
%               particular along with the simulated data available at:
%               https://www.geoq.uni-hannover.de/mock.html
%
% Written by Majid Naeimi, IfE, Hannover, 2015-08
% Updated by Neda Darbeheshti, AEI, Hannover, 2018-02 for Time Derivative
%         of the Transformation Matrix

%%
% The Earth's angular velocity in rad/s
we = 7.29211514670698e-05;

Tjd = grace_gps_time/86400 + 2451545;
sdt = (Tjd-2453491.5) * 86400 * we - 2.46276246875459;
rot_mat_dot = we*[-sin(sdt) -cos(sdt) zeros(length(sdt),1)...
    cos(sdt) -sin(sdt) zeros(length(sdt),1)...
    zeros(length(sdt),1) zeros(length(sdt),1) zeros(length(sdt),1)];
RotMati2e_dot = reshape(rot_mat_dot',3,3,[]);
