function [sc,rows,cols] = cs2sc(field,backval)

% CS2SC(FIELD,backval) converts the square (L+1)x(L+1) matrix FIELD, containing
% spherical harmonics coefficients in |C\S| storage format into a 
% rectangular (L+1)x(2L+1) matrix in  /S|C\format.
% The argument backval is optional and describes the matrix entries, 
% where m > l. Default is 0!
%
% Written by Nico Sneeuw, IAPG, TU-Munich 1994-07-22
% revision history
% - 07/99, Matthias Weigelt - V5 adaptation, eliminiation of TRAPSTRIP
% - 07/10, Matthias Weigelt - file is now insensitive to SC-format input
%                           - added output rows and cols

%%

if nargin == 1, backval = 0; end
[rows,cols] = size(field);
if (rows~=cols) && (cols~=2*rows-1)
    error('Input neither in cs nor in sc format');
elseif cols==2*rows-1
    sc = field;
else
    lmax = rows-1;
    c    = tril(field);
    s    = rot90(triu(field,1),-1);
    mask = backval*ones(lmax+1,2*lmax+1);
    a    = fliplr(triu(mask(:,1:cols-1)));
    b    = triu(mask(:,cols:2*lmax+1),1);
    sc   = [a b] + [s(:,2:lmax+1) c];
end
