function dv= dv_geoidn(EGM,n_max)
% DV_GEOIDN reads an Earth's gravity field model and plots the degree
% variances.
%
% input: 
%   EGM:gravity model, order wise (n: 0 1 1 2 2 2 3 3 3 3... m:0 0 1 0 1 2 0 1 2 3...)
%   n_max:maximum degree and order
%
% output:
%   plot of square root of degree variances
%
% example: 
%    dv= dv_geoidn(egm96,60)
%
% updated on 03/04/2017

format long g

F1 = EGM(:,3).^2 + EGM(:,4).^2;
F1r = F1;
F1r(1:3) = [];
F2 = F1r;
for n = 2:n_max
     dv(n-1) = sqrt(sum(F2(1:n+1)));
     F2(1:n+1) = [];
end

fs = 12;
set(gcf,'PaperPositionMode','auto')
set(gca,'FontSize',fs);
semilogy(2:n_max,dv(1:end),'.-','LineWidth',3,'MarkerSize',20)
xlabel('Spherical harmonic degree n')
ylabel('Square root of degree variances')
grid on
end
