function [Hi_tilda, Y_star] = hmat_pos(X0,NOCs,no)

% This function makes the Htilde matrix.
% References:-McCullough CM (2017) Gravity Field Estimation for Next Generation Satellite
%             Missions,  page 97, equation (4.4)
%             Liu(2008), page 28, equation (2.51) 
%            -Statistical Orbit Determination (Tapley et al., 2004) 
% 
% Input:        X0 = state vector including [RA; RdotA; PHI]
%               NOCs = total number of coefficients to be estimated
%               no = number of observations:3 (for positions) or 6 for (positios + velocities)
% 
% Outputs:      Hi_tilda = [dRA/dRA; dRA/dRdotA; dRA/dRB; dRA/dRdotB; dRA/dKlm]
% 
% 
% Written by  Florian Wöske, ZARM Uni Bremen,2018-11

%% calculate gnv partials w.r.t SHC
    % Extract the current state transition matrix:
    phi = reshape(X0(12+1:end), 12, 12+NOCs);
    % Extract the partials from the current state transition matrix:
    % if no == 3 always positions 
    dr1_dklm=phi(1:3,13:end);
    if no == 6
        dr2_dklm=phi(7:9,13:end);
    end

    I = eye(3,3);
    Z = zeros(3,3);

    % fill Hi_tilda matrix
    if no == 3
        Hi_tilda=[I, Z, Z, Z, dr1_dklm];
        % observation is directly x,y,z
        Y_star = X0(1:3);
    elseif no == 6
        Hi_tilda=[I, Z, Z, Z, dr1_dklm; Z, Z, I, Z, dr2_dklm];
        % observation is directly x,y,z
        Y_star =[X0(1:3); X0(7:9)];
    end

end
