function GiR  = inter_sat_dist(Xref)

% INTER_SAT_DIST calculates range and range rate from position and velocity of
% two satellites.
%
% Input:
%
%   Xref = state vector of two satellites [RA; RdotA; RB; RdotB]
%
% Outputs:
%
%   GiR = range and range rate [Rho Rhodot]
%
% Written by Neda Darbeheshti, AEI Hannover, 2018-05-25

%%

R1s = Xref(1:3); %m (1x3)
V1s = Xref(4:6); %m/s (1x3)
R2s = Xref(7:9);
V2s = Xref(10:12);

% RANGE %m;
pL21s = norm(R2s-R1s);

% RANGE RATE %m/s
pdotL21s = ((((R2s(1)-R1s(1))*(V2s(1)- V1s(1))) + ((R2s(2)-R1s(2))*...
            (V2s(2) - V1s(2))) + ((R2s(3) - R1s(3))*(V2s(3)-V1s(3))))/pL21s);

GiR = [pL21s; pdotL21s];
