function [cs,rows,cols] = sc2cs(field)

% SC2CS(FIELD) converts the rectangular (L+1)x(2L+1) matrix FIELD, containing
% spherical harmonics coefficients in /S|C\ storage format into a
% square (L+1)x(L+1) matrix in |C\S| format.
%
% Written by Nico Sneeuw, TU Munich, 1994-07-22
% revision history
% - 07/10, Matthias Weigelt - file is now insensitive to CS-format input
%                           - output rows and cols added

%%

[rows,cols] = size(field);
if (rows~=cols) && (cols~=2*rows-1)
    error('Input neither in cs nor in sc format');
elseif cols == rows
    cs = field;
else
    lmax = rows-1;
    c    = field(:,lmax+1:2*lmax+1);
    s    = [zeros(lmax+1,1) field(:,1:lmax)];
    cs   = tril(c) + triu(rot90(s),1);
end
