#!/bin/bash
#
# This script downloads the input data. You need wget und unzip to run it.
#
# ./get_input_data.sh
#

URL="https://seafile.projekt.uni-hannover.de/f/3ee8fef6c6cb485489b4/?dl=1"
INPUT_DATA=input_data.zip

download_data(){
    echo "Downloading data from $URL..."
    wget --content-disposition "url?raw=1" -U mozilla "$URL" -O $INPUT_DATA
    echo "Done."
}

set_up(){
    echo "Start extracting data file..."
    unzip $INPUT_DATA -d input_data/
    echo "Done."
    echo "Removing zip file"
    rm -f input_data.zip
    echo "Done."
}

clean_up(){
    echo "Removing subdirectories from input directory."
    rm -rf input_data/*
    echo "Done."
    echo "Removing files from input directory."
    rm -f input_data/*
    echo "Done."
}

get_data(){
    if [[ -d input_data/ ]]; then
        echo "Directory 'input_data/' already exists."
        if [[ -f input_data/EGM96.gfc ]]; then
            echo "There is already data in it."
            read -r -p "Cleanup and download again? [y/N]" response
            case $response in
                [yY][eE][sS]|[yY])
                    clean_up
                    download_data
                    set_up
                    ;;
                *)
                    echo "Aborting."
                    exit
                    ;;
            esac
        else
            download_data
            set_up
        fi
    else
        download_data
        set_up
    fi
}

main(){
    get_data
}

main
